"""
:authors: two-it2022
:license: Apache License, Version 0.5, see LICENSE file

:copyright: (c) 2022 two-it2022
"""

from .main import *


__author__ = 'two-it2022'
__version__ = '0.0.5'
__email__ = 'kodland.group@gmail.com'
